@@ -17,7 +17,7 @@ class AsyncShell:
     def executor(self) -> futures.Executor:
         return super().executor
 
-    def parallel(self, *args, **kwargs) -> functional.AwaitableGenerator:
+    def parallel(self, *args, **kwargs) -> "functional.AwaitableGenerator":
         return super().parallel(*args, **kwargs)
 
     async def run(self, *args, **kwargs) -> CompletedProcess:
